##  Summary
In this tutorial, we explored how to use GraphQL queries when creating a custom report. You learned how to:
  * Use the lx.executeGraphQL method of the LeanIX Reporting Library, which enables you to run custom GraphQL queries
  * Calculate the average completion score for each fact sheet type, which is important for data analysis


YesNo
Send
